function edgeVec=ElementContributionEdge(corners,gNFunc)
% [...] =  ElementContributionEdge(...)
%   compute the vector contribution due to one line segement of the Neumann boundary
%
% edgeVec=ElementContributionEdge(corners,gNFunc)
%  corners  coordinates of the two points forming the line segment
%  gNFunc  function file or scalar for the coefficient function
%  edgeVec vector contribution to the RHS of the linear equation

% this is a Gauss integration
p1=(corners(1,:)+corners(2,:))/2 + (corners(1,:)-corners(2,:))/(2*sqrt(3)); 
p2=(corners(1,:)+corners(2,:))/2 - (corners(1,:)-corners(2,:))/(2*sqrt(3)); 
if is_scalar(gNFunc) g = gNFunc*ones(2,1);
       else          g=feval(gNFunc,[p1;p2]);endif

w=(1-1/sqrt(3))/2;

edgeVec=norm(corners(2,:)-corners(1,:))/2*[(1-w)*g(1)+w*g(2);w*g(1)+(1-w)*g(2)];
endfunction
