clear *  # clear all variables
r=1.0;   # define the variables for the geometry
R=2.5;
global h=0.1;
H=0.5;

N=201;   # number of grid points for integration

area=0.001;  # area of typical triangle

xy=[0,0,1; R,0,2; R,H,2; r,H,1; r,h,1; 0,h,2];  # define geometriy
CreateMeshTriangle("cap",xy,area)               # ceate mesh and store in file
[nodes,elem,edges]=ReadMeshTriangle("./cap.1"); # read into octave
ShowMesh(nodes,elem)                            # display the mesh
disp("hit return");pause();


# define the function for the voltages on upper and lower edge
clear volt
function res = volt(xy)
global h;
[n,m]=size(xy);
res=zeros(n,1);
for k=1:n
  if (xy(k,2)<h/2) res(k)=0;
  else res(k)=1;endif
endfor
endfunction

# create the linear system to be solved
[A,b,n2d]=FEMEquation(nodes,elem,edges,nodes(:,1),0,0,'volt',0);
u=FEMSolveSym(nodes,A,b,n2d,'volt');  # solve the system

ShowSolution(nodes,elem,u)            # display the solution
disp("hit return");pause();

ShowLevelCurves(nodes,elem,u,linspace(0,1,11)); # display level curves
disp("hit return");pause();


# evaluate the gradient along the lower edge
x=linspace(0,R,N); 
y=0.0*ones(1,N);
[uVal,grad]=FEMValue([x;y]',nodes,elem,u);

plot(x,grad(:,2))   # show the vertical component of the gradient

# trapezoidal integration to compute flux
flux = 2*(x*grad(:,2)-x(1)*grad(1,2)/2-x(N)*grad(N,2)/2)*R/(N-1)*(h/r**2)
